==> dde-network-core_1.0.64.orig.tar.xz: dde-network-core-1.0.64/dock-network-plugin/translations/dock-network-plugin_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu" version="2.1">
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Hálózat</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokoll</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Biztonság típusa</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Sáv</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Csatorna</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Felület</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC cím</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Hálózati maszk</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Átjáró</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Elsődleges DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Előtag</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Sebesség</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Eszköz letiltva</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Csatlakoztatva, de nincs internet hozzáférés</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nincs csatlakozva</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>A hálózati kábel kihúzva</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Csatlakozás</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Hitelesítés</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>IP cím lekérése</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Csatlakozva</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Szétkapcsolva</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP cím ütközés</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Sikertelen</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Cím lekérése</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Vezetékes hálózat </translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Vezetékes hálózat %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Vezeték nélküli hálózat</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Vezeték nélküli hálózat %1 </translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Eszköz letiltva</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>A hálózati kábel kihúzva</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nincs csatlakozva</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Csatlakozás</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Csatlakoztatva, de nincs internet hozzáférés</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>A kapcsolódás sikertelen</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP cím ütközés</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Vezetékes kapcsolat letiltása</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Vezetékes kapcsolat engedélyezése</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Vezeték-nélküli kapcsolat letiltása</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Vezeték nélküli kapcsolat engedélyezése</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Hálózat letiltása</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Hálózat engedélyezése</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Hálózati beállítások</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.2.orig.tar.xz: dde-network-core-1.1.2/dock-network-plugin/translations/dock-network-plugin_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Vezeték nélküli hálózat</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Vezetékes hálózat </translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Hálózat</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Csatlakozás rejtett hálózathoz</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Jelszó</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Kapcsolódás</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Név (SSID)</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokoll</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Biztonság típusa</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Csatorna</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Sáv</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Felület</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC cím</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Hálózati maszk</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Átjáró</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Elsődleges DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Előtag</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Sebesség</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Eszköz letiltva</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Csatlakoztatva, de nincs internet hozzáférés</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nincs csatlakozva</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>A hálózati kábel kihúzva</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Csatlakozás</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Hitelesítés</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>IP cím lekérése</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Csatlakozva</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Szétkapcsolva</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP cím ütközés</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Sikertelen</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Cím lekérése</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Vezetékes hálózat </translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Vezetékes hálózat %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Vezeték nélküli hálózat</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Vezeték nélküli hálózat %1 </translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Eszköz letiltva</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>A hálózati kábel kihúzva</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nincs csatlakozva</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Csatlakozás</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Csatlakoztatva, de nincs internet hozzáférés</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>A kapcsolódás sikertelen</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP cím ütközés</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Vezetékes kapcsolat letiltása</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Vezetékes kapcsolat engedélyezése</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Vezeték-nélküli kapcsolat letiltása</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Vezeték nélküli kapcsolat engedélyezése</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Hálózat letiltása</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Hálózat engedélyezése</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Hálózati beállítások</translation>
    </message>
</context>
</TS>
